@@ -31,8 +31,14 @@ class ImagingTestType(ModelSQL, ModelView):
     'Medical Imaging Study Type'
     __name__ = 'gnuhealth.imaging.test.type'
 
-    code = fields.Char('Code', required=True)
-    name = fields.Char('Name', required=True)
+    code = fields.Char(
+        'Code', required=True,
+        help="Suggest use values of DICOM "
+        "Modality (0008,0060) tag.")
+    name = fields.Char(
+        'Name', required=True, translate=True,
+        help="Suggest use descriptions of DICOM "
+        "Modality (0008,0060) tag.")
 
 
 class ImagingTest(ModelSQL, ModelView):
@@ -40,7 +46,7 @@ class ImagingTest(ModelSQL, ModelView):
     __name__ = 'gnuhealth.imaging.test'
 
     code = fields.Char('Code', required=True)
-    name = fields.Char('Name', required=True)
+    name = fields.Char('Name', required=True, translate=True)
     test_type = fields.Many2One(
         'gnuhealth.imaging.test.type', 'Type',
         required=True)
@@ -88,6 +94,7 @@ class ImagingTestRequest(Workflow, ModelSQL, ModelView):
 
     comment = fields.Text('Additional Information')
     request = fields.Char('Order', readonly=True)
+    request_line = fields.Char('Order line', readonly=True)
     urgent = fields.Boolean('Urgent')
 
     @classmethod
@@ -120,6 +127,7 @@ class ImagingTestRequest(Workflow, ModelSQL, ModelView):
     def default_doctor():
         return get_health_professional()
 
+    @classmethod
     def generate_code(cls, **pattern):
         Config = Pool().get('gnuhealth.sequences')
         config = Config(1)
@@ -131,9 +139,15 @@ class ImagingTestRequest(Workflow, ModelSQL, ModelView):
     @classmethod
     def create(cls, vlist):
         vlist = [x.copy() for x in vlist]
+        count = len(vlist)
+        num = 1
         for values in vlist:
             if not values.get('request'):
                 values['request'] = cls.generate_code()
+            if not values.get('request_line'):
+                values['request_line'] = f'{values["request"]}-{count:02}-{num:02}'
+            num = num + 1
+
         return super(ImagingTestRequest, cls).create(vlist)
 
     @classmethod
@@ -142,6 +156,7 @@ class ImagingTestRequest(Workflow, ModelSQL, ModelView):
             default = {}
         default = default.copy()
         default['request'] = None
+        default['request_line'] = None
         default['date'] = cls.default_date()
         return super(ImagingTestRequest, cls).copy(tests, default=default)
 
