@@ -1,37 +1,28 @@
-# -*- coding: utf-8 -*-
-##############################################################################
-#
-#    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2022 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
-#
-#
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
-#
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-##############################################################################
-from datetime import datetime
-from trytond.model import ModelView, ModelSingleton, ModelSQL, fields, \
-    ValueMixin
-from trytond.pyson import Eval, Not, Bool, PYSONEncoder
-from trytond.pool import Pool
-from trytond import backend
-from trytond.tools.multivalue import migrate_property
+#!/usr/bin/env python
 
+# SPDX-FileCopyrightText: 2008-2023 Luis Falcón <falcon@gnuhealth.org>
+# SPDX-FileCopyrightText: 2011-2023 GNU Solidario <health@gnusolidario.org>
+
+# SPDX-License-Identifier: GPL-3.0-or-later
+
+#########################################################################
+#   Hospital Management Information System (HMIS) component of the      #
+#                       GNU Health project                              #
+#                   https://www.gnuhealth.org                           #
+#########################################################################
+#                    HEALTH NTD DENGUE package                          #
+#                health_ntd_dengue.py: main module                      #
+#########################################################################
+
+from datetime import datetime
+from trytond.model import ModelView, ModelSQL, fields
+from trytond.pyson import Eval, Not, Bool
+from trytond.pool import Pool
 
 
 __all__ = ['DengueDUSurvey']
 
+
 class DengueDUSurvey(ModelSQL, ModelView):
     'Dengue DU Survey'
     __name__ = 'gnuhealth.dengue_du_survey'
@@ -101,7 +92,6 @@ class DengueDUSurvey(ModelSQL, ModelView):
     def default_survey_date():
         return datetime.now()
 
-
     @classmethod
     def generate_code(cls, **pattern):
         Config = Pool().get('gnuhealth.sequences')
