@@ -1,25 +1,10 @@
-#############################################################################
+# Copyright (C) 2008-2023 Luis Falcon <lfalcon@gnusolidario.org>
+# Copyright (C) 2011-2023 GNU Solidario <health@gnusolidario.org>
+# SPDX-FileCopyrightText: 2008-2023 Luis Falcón <falcon@gnuhealth.org>
+# SPDX-FileCopyrightText: 2011-2023 GNU Solidario <health@gnusolidario.org>
 #
-#    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2022 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
-#
-#
-#
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
-#
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-##############################################################################
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 import datetime
 from trytond.model import ModelView
 from trytond.wizard import Wizard, StateTransition, StateView, Button
@@ -73,7 +58,7 @@ class CreateServiceInvoice(Wizard):
         for service in services:
             if service.state == 'invoiced':
                 raise ServiceAlreadyInvoiced(
-                    gettext('health_service.msg_service_already_invoiced'))
+                    gettext('health_services.msg_service_already_invoiced'))
 
             if service.invoice_to:
                 party = service.invoice_to
@@ -125,7 +110,7 @@ class CreateServiceInvoice(Wizard):
             party_address = Party.address_get(party, type='invoice')
             if not party_address:
                 raise NoInvoiceAddress(
-                    gettext('health_service.msg_no_invoice_address'))
+                    gettext('health_services.msg_no_invoice_address'))
             invoice_data['invoice_address'] = party_address.id
             invoice_data['reference'] = service.name
 
@@ -141,7 +126,7 @@ class CreateServiceInvoice(Wizard):
                     acct_config.default_customer_payment_term.id
             else:
                 raise NoPaymentTerm(
-                    gettext('health_service.msg_no_payment_term'))
+                    gettext('health_services.msg_no_payment_term'))
 
             # Invoice Lines
             seq = 0
