@@ -160,6 +160,7 @@ class PatientAmbulatoryCare(Workflow, metaclass=PoolMeta):
                     ambulatory.patient.name.customer_location.id
                 move_info['unit_price'] = \
                     medicament.medicament.name.list_price
+                move_info['cost_price'] = medicament.medicament.name.cost_price
                 if medicament.lot:
                     if medicament.lot.expiration_date and \
                             medicament.lot.expiration_date < Date.today():
@@ -339,6 +340,7 @@ class PatientRounding(Workflow, ModelSQL, ModelView):
                 move_info['to_location'] = \
                     rounding.name.patient.name.customer_location.id
                 move_info['unit_price'] = medicament.medicament.name.list_price
+                move_info['cost_price'] = medicament.medicament.name.cost_price
                 if medicament.lot:
                     if medicament.lot.expiration_date \
                             and medicament.lot.expiration_date < Date.today():
@@ -356,6 +358,7 @@ class PatientRounding(Workflow, ModelSQL, ModelView):
                 move_info['to_location'] = \
                     rounding.name.patient.name.customer_location.id
                 move_info['unit_price'] = medical_supply.product.list_price
+                move_info['cost_price'] = medical_supply.product.cost_price
                 if medical_supply.lot:
                     if medical_supply.lot.expiration_date \
                             and medical_supply.lot.expiration_date < \
