@@ -5,7 +5,7 @@
 
 # This file is part of GNU Health.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from trytond.exceptions import UserError, UserWarning
+from trytond.exceptions import UserError
 from trytond.model.exceptions import ValidationError
 
 
@@ -16,8 +16,14 @@ class EndDateBeforeStart(ValidationError):
 class ORNotAvailable(ValidationError):
     pass
 
+
 class OperatingRoomAndDateRequired(UserError):
     pass
 
+
+class EndReservationBeforeStart(UserError):
+    pass
+
+
 class SurgeryDone(UserError):
     pass
