@@ -160,10 +160,7 @@ class TrytonDAVInterface(iface.dav_interface):
     @staticmethod
     def get_dburi(uri):
         # URI format : http[s]://<servername>:8080/<dbname>/Calendars/<CalendarName>
-        if isinstance(uri[2], str):
-            uri = urllib.parse.urlsplit(uri)[2]
-        else:
-            uri = urllib.parse.urlsplit(uri)[2].decode()
+        uri = urllib.parse.urlsplit(uri)[2]
         
         if uri and uri[0] == '/':
             uri = uri[1:]
@@ -194,14 +191,6 @@ class TrytonDAVInterface(iface.dav_interface):
             scheme, netloc, path, params, query, fragment = \
                 urllib.parse.urlparse(uri)
 
-            if not isinstance(uri, str):
-                scheme = scheme.decode()
-                netloc = netloc.decode()
-                path = path.decode()
-                params = params.decode()
-                query = query.decode()
-                fragment = fragment.decode()
-
             if path[-1:] != '/':
                 path = path + '/'
             for child in Collection.get_childs(dburi, filter=filter,
@@ -224,8 +213,6 @@ class TrytonDAVInterface(iface.dav_interface):
 
     def get_data(self, uri, range=None):
 
-        uri = uri.decode()
-
         dbname, dburi = self._get_dburi(uri)
         if not dbname or (self.exists(uri) and self.is_collection(uri)):
             res = ('<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 '
@@ -289,6 +276,7 @@ class TrytonDAVInterface(iface.dav_interface):
         return res[range[0]:range[1]]
 
     def put(self, uri, data, content_type=''):
+        res = []
         dbname, dburi = self._get_dburi(uri)
         if not dbname or not dburi:
             raise DAV_Forbidden
@@ -306,7 +294,7 @@ class TrytonDAVInterface(iface.dav_interface):
             raise DAV_Error(500)
         if res:
             uparts = list(urllib.parse.urlsplit(uri))
-            uparts[2] = res.encode()
+            uparts[2] = res
             res = urllib.parse.urlunsplit(uparts)
         return res
 
@@ -348,7 +336,7 @@ class TrytonDAVInterface(iface.dav_interface):
     def _get_dav_displayname(self, uri):
         dbname, dburi = self._get_dburi(uri)
         if not dbname or not dburi:
-            return uri.decode().split('/')[-1]
+            return uri.split('/')[-1]
         pool = Pool(Transaction().database.name)
         try:
             Collection = pool.get('webdav.collection')
@@ -412,7 +400,7 @@ class TrytonDAVInterface(iface.dav_interface):
         except Exception as exception:
             self._log_exception(exception)
             raise DAV_Error(500)
-        return res
+        return float(res)
 
     def get_lastmodified(self, uri):
         dbname, dburi = self._get_dburi(uri)
@@ -428,7 +416,7 @@ class TrytonDAVInterface(iface.dav_interface):
         except Exception as exception:
             self._log_exception(exception)
             raise DAV_Error(500)
-        return res
+        return float(res)
 
     def rmcol(self, uri):
         dbname, dburi = self._get_dburi(uri)
