@@ -1,8 +1,9 @@
-# This file is part of GNU Health.  The COPYRIGHT file at the top level of
-# this repository contains the full copyright notices and license terms.
-"""
-%prog [options]
-"""
+# SPDX-FileCopyrightText: 2012-2017 Cédric Krier
+# SPDX-FileCopyrightText: 2017-2023 GNU Solidario <health@gnusolidario.org>
+# SPDX-FileCopyrightText: 2017-2023 Luis Falcon <falcon@gnuhealth.org>
+#
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 import logging
 import logging.config
 import logging.handlers
